**To delete a provisioning artifact**

The following ``delete-provisioning-artifact`` example deletes the specified provisioning artifact. ::

    aws servicecatalog delete-provisioning-artifact \
        --product-id prod-abc2uebuplcpw \
        --provisioning-artifact-id pa-pqabcddii7ouc

This command produces no output.
